@@ -36,10 +36,21 @@ void *burn_alloc_mem(size_t size, size_t count, int flag);
 		ret= -1; goto ex; \
 	} }
 
+#define BURN_ALLOC_MEM_VOID(pt, typ, count) { \
+	pt= (typ *) burn_alloc_mem(sizeof(typ), (size_t) (count), 0); \
+	if(pt == NULL) { \
+		goto ex; \
+	} }
+
 #define BURN_FREE_MEM(pt) { \
 	if(pt != NULL) \
 		free((char *) pt); \
 	}
 
 
+/* B20122 */
+int burn_grab_prepare_sig_action(int *signal_action_mem, int flag);
+int burn_grab_restore_sig_action(int signal_action_mem, int flag);
+
+
 #endif /* BURN__INIT_H */
