@@ -2,7 +2,7 @@
 /*
   Class struct of libisoburn.
 
-  Copyright 2007 - 2011 Vreixo Formoso Lopes <metalpain2002@yahoo.es>
+  Copyright 2007 - 2012 Vreixo Formoso Lopes <metalpain2002@yahoo.es>
                     and Thomas Schmitt <scdbackup@gmx.net>
   Provided under GPL version 2 or later.
 */
@@ -494,8 +494,11 @@ struct isoburn_imgen_opts {
     /**
      * Store as ECMA-119 Directory Record timestamp the mtime
      * of the source rather than the image creation time.
+     * The same can be ordered for Joliet and ISO 9660:1999
      */
     unsigned int dir_rec_mtime :1;
+    unsigned int joliet_rec_mtime :1;
+    unsigned int iso1999_rec_mtime :1;
 
     /**
      * Write AAIP as extension according to SUSP 1.10 rather than SUSP 1.12.
