@@ -1,7 +1,7 @@
 
 /* xorriso - creates, loads, manipulates and burns ISO 9660 filesystem images.
 
-   Copyright 2007-2010 Thomas Schmitt, <scdbackup@gmx.net>
+   Copyright 2007-2011 Thomas Schmitt, <scdbackup@gmx.net>
 
    Provided under GPL version 2 or later.
 
@@ -284,7 +284,11 @@ int Sectorbitmap_from_file(struct SectorbitmaP **o, char *path, char *msg,
 {
  int ret, fd= -1, sectors, sector_size, i, todo, map_size, skip;
  unsigned char *map;
- unsigned char buf[1024];
+ unsigned char *buf;
+
+ buf= TSOB_FELD(unsigned char, 1024);
+ if(buf == NULL)
+   return(-1);
 
  *os_errno= 0;
  if(msg != NULL)
@@ -296,7 +300,7 @@ int Sectorbitmap_from_file(struct SectorbitmaP **o, char *path, char *msg,
      strcpy(msg, "Cannot open path ");
      Text_shellsafe(path, msg+strlen(msg), 0);
    }
-   return(0);
+   {ret= 0; goto ex;}
  }
  ret= read(fd, buf, 32);
  if(ret < 32) {
@@ -354,6 +358,8 @@ wrong_filetype:;
 ex:;
  if(fd != -1)
    close(fd);
+ if(buf != NULL)
+   free(buf);
  if(ret <= 0)
    Sectorbitmap_destroy(o, 0);
  return(ret);
@@ -799,8 +805,10 @@ int Xorriso_check_media_setup_job(struct XorrisO *xorriso,
    } else if(strncmp(argv[i], "what=", 5) == 0) {
      if(strcmp(argv[i]+5, "tracks") == 0)
        job->mode= 0;
-     else if(strcmp(argv[i]+5, "disc")== 0)
+     else if(strcmp(argv[i]+5, "image")== 0)
        job->mode= 1;
+     else if(strcmp(argv[i]+5, "disc")== 0)
+       job->mode= 2;
      else {
 unknown_value:;
        sprintf(xorriso->info_text,
@@ -829,14 +837,16 @@ int Xorriso_check_media_list_job(struct XorrisO *xorriso,
                                  char *report, int flag)
 {
  int all, ret;
- char default_report[161], quality_name[80];
+ char *default_report= NULL, quality_name[80];
  struct CheckmediajoB *dflt= NULL;
 
+ Xorriso_alloc_meM(default_report, char, 161);
+
  all= !(flag&1);
  report[0]= 0;
  ret= Checkmediajob_new(&dflt, 0);
  if(ret <= 0)
-   return(-1);
+   {ret= -1; goto ex;}
  sprintf(report, "-check_media_defaults");
  if(!all)
    strcat(report, " reset=now");
@@ -911,6 +921,7 @@ ex:;
  Checkmediajob_destroy(&dflt, 0);
  sprintf(default_report, "-check_media_defaults reset=now %s",
          xorriso->list_delimiter);
+ Xorriso_free_meM(default_report);
  if(ret > 0 && strcmp(report, default_report) == 0)
    return(2);
  return(ret);
@@ -1060,15 +1071,13 @@ int Xorriso_spotlist_to_sectormap(struct XorrisO *xorriso,
 int Xorriso_open_job_data_to(struct XorrisO *xorriso,
                              struct CheckmediajoB *job, int flag)
 {
- char sfe[5*SfileadrL];
-
  if(job->data_to_path[0] == 0)
    return(2);
  job->data_to_fd= open(job->data_to_path, O_RDWR | O_CREAT,
                        S_IRUSR | S_IWUSR);
  if(job->data_to_fd == -1) {
-   sprintf(xorriso->info_text, "Cannot open path %s",
-           Text_shellsafe(job->data_to_path, sfe, 0));
+   sprintf(xorriso->info_text, "Cannot open path ");
+   Text_shellsafe(job->data_to_path, xorriso->info_text, 1);
    Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, errno, "FAILURE", 0);
    return(0);
  }
