@@ -2011,7 +2011,7 @@ int Xorriso_check_md5_range(struct XorrisO *xorriso, off_t start_lba,
    xorriso->pacifier_count+= data_count; 
    xorriso->pacifier_byte_count+= data_count;
    Xorriso_pacifier_callback(xorriso, "content bytes read",
-                             xorriso->pacifier_count, 0, "", 0);
+                             xorriso->pacifier_count, 0, "", 8);
  }
  iso_md5_end(&ctx, data_md5);
  ret= 1;
@@ -2115,6 +2115,8 @@ int Xorriso_check_interval(struct XorrisO *xorriso, struct SpotlisT *spotlist,
  char *comparison= "", *sev_text= "DEBUG", *tag_type_name= "";
 
  Xorriso_alloc_meM(data, char, 64*1024);
+ if(read_chunk > 32)
+   read_chunk= 32;
 
  ret= Xorriso_get_drive_handles(xorriso, &dinfo, &drive,
                                 "on attempt to check media readability",
@@ -2419,8 +2421,8 @@ failed_to_write:;
      xorriso->pacifier_count+= to_read;
      if(post_read_time - xorriso->last_update_time >=
         xorriso->pacifier_interval)
-       Xorriso_pacifier_callback(xorriso, "sectors examined",
-                      xorriso->pacifier_count, xorriso->pacifier_total, "", 0);
+       Xorriso_pacifier_callback(xorriso, "blocks read",
+                 xorriso->pacifier_count, xorriso->pacifier_total, "", 8 | 16);
    }
  }
  if(prev_quality >= 0) {
@@ -2639,15 +2641,17 @@ libburn_whole_disc:;
      Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "FAILURE", 0);
      {ret= 0; goto ex;}
    }
+   blocks-= start_lba;
    xorriso->pacifier_total= blocks;
-   ret= Xorriso_check_interval(xorriso, *spotlist, job, 0, blocks,
+   ret= Xorriso_check_interval(xorriso, *spotlist, job, start_lba, blocks,
                                read_chunk, 0, 0);
    if(ret <= 0)
      goto ex;
  }
 
- Xorriso_pacifier_callback(xorriso, "sectors examined",
-                      xorriso->pacifier_count, xorriso->pacifier_total, "", 1);
+ Xorriso_pacifier_callback(xorriso, "blocks read",
+                      xorriso->pacifier_count, xorriso->pacifier_total, "",
+                      1 | 8 | 16 | 32);
  ret= 1;
 ex:;
 
