@@ -1,7 +1,7 @@
 
 /* xorriso - creates, loads, manipulates and burns ISO 9660 filesystem images.
 
-   Copyright 2007-2011 Thomas Schmitt, <scdbackup@gmx.net>
+   Copyright 2007-2012 Thomas Schmitt, <scdbackup@gmx.net>
 
    Provided under GPL version 2 or later.
 
@@ -382,11 +382,50 @@ no_volunteer:;
  /* Perform actions */
  Xorriso_option_report_about(xorriso, "NOTE", 0);
  if(do_version) {
-   sprintf(xorriso->result_line, "Cdrecord 2.01-Emulation Copyright (C) 2011 see libburnia-project.org xorriso\n");
+   sprintf(xorriso->result_line, "Cdrecord 2.01-Emulation Copyright (C) 2012 see libburnia-project.org xorriso\n");
    Xorriso_result(xorriso, 1);
    Xorriso_option_version(xorriso, 0);
+ }
+
+ if(do_help) {
+   Xorriso_cdrskin_help(xorriso, 0);
+ }
+ if(strcmp(blank_mode, "help")==0) {
+   for(i= 0; strcmp(blank_help[i], "@End_of_helptexT@")!=0; i++) {
+     sprintf(xorriso->info_text, "%s\n", blank_help[i]);
+     Xorriso_info(xorriso,0);
+   }
+ }
+ if(do_help || strcmp(blank_mode, "help") == 0 || do_version) {
    ret= 1; goto ex;
  }
+
+ if(do_verbous<=0)
+   report_about= "NOTE";
+ else if(do_verbous<=2)
+   report_about= "UPDATE";
+ else if(do_verbous==3)
+   report_about= "DEBUG";
+ else
+   report_about= "ALL";
+ Xorriso_option_report_about(xorriso, report_about, 0);
+
+ if(do_scanbus) {
+   if(do_scanbus==1)
+     /* >>> would need -scanbus compatible output and input format */;
+   else
+     Xorriso_option_devices(xorriso, 0);
+   ret= 1; goto ex;
+ }
+
+ if(!(do_checkdrive || do_atip || do_toc || blank_mode[0] || track_source[0] ||
+      do_eject || do_msinfo)) {
+   sprintf(xorriso->info_text,
+           "-as cdrskin: No option specified, which would cause an action.");
+   Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "SORRY", 0);
+   ret= 1; goto ex;
+ }
+
  if(do_waiti) {
    sprintf(xorriso->info_text,
        "xorriso: Option -waiti pauses program until input appears at stdin\n");
@@ -402,7 +441,7 @@ no_volunteer:;
    sprintf(xorriso->info_text, "xorriso: Option -waiti pausing is done.\n");
  }
  if(dev_adr[0]) {
-   hflag= 2 | 32 | 64;
+   hflag= 2 | 64;       /* ts B11201 no more:  | 32 */
    if(!do_grow)
      hflag|= 8; /* consider overwriteables as blank */
    ret= Xorriso_option_dev(xorriso, dev_adr, hflag);
@@ -410,29 +449,6 @@ no_volunteer:;
      goto ex;
  }
 
- if(do_help) {
-   Xorriso_cdrskin_help(xorriso, 0);
-   ret= 1; goto ex;
- }
- if(do_scanbus) {
-   if(do_scanbus==1)
-     /* >>> would need -scanbus compatible output and input format */;
-   else
-     Xorriso_option_devices(xorriso, 0);
-   ret= 1; goto ex;
- }
- if(strcmp(blank_mode, "help")==0) {
-   for(i= 0; strcmp(blank_help[i], "@End_of_helptexT@")!=0; i++) {
-     sprintf(xorriso->info_text, "%s\n", blank_help[i]);
-     Xorriso_info(xorriso,0);
-   }
-   ret= 1; goto ex;
- }
-
- if(!(do_checkdrive || do_atip || do_toc || blank_mode[0] || track_source[0] ||
-      do_eject || do_msinfo))
-   {ret= 1; goto ex;}
-
  if(xorriso->out_drive_handle==NULL) {
    sprintf(xorriso->info_text, "-as %s: No output drive selected", whom);
    Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "FAILURE", 0);
@@ -453,16 +469,6 @@ no_volunteer:;
      goto ex;
  }
 
- if(do_verbous<=0)
-   report_about= "SORRY";
- else if(do_verbous<=2)
-   report_about= "UPDATE";
- else if(do_verbous==3)
-   report_about= "DEBUG";
- else
-   report_about= "ALL";
- Xorriso_option_report_about(xorriso, report_about, 0);
-
  if(do_checkdrive) {
    ret= Xorriso_atip(xorriso, 2-(do_checkdrive==2));
    if(ret<=0)
@@ -990,7 +996,7 @@ int Xorriso_genisofs(struct XorrisO *xorriso, char *whom,
  continue;
    if(strcmp(argpt, "-version")==0) {
      sprintf(xorriso->result_line,
-"mkisofs 2.01-Emulation Copyright (C) 2011 see libburnia-project.org xorriso\n"
+"mkisofs 2.01-Emulation Copyright (C) 2012 see libburnia-project.org xorriso\n"
             );
      fd= xorriso->dev_fd_1;
      if(fd<0)
@@ -1722,6 +1728,9 @@ is_pathspec_2:;
      */
      if(with_emul_toc == 0)
        xorriso->no_emul_toc|= 1;
+     /* mkisofs records mtime in ECMA-119 and Joliet
+     */
+     Xorriso_relax_compliance(xorriso, "rec_mtime", 0);
    }
  continue; /* regular bottom of loop */
 problem_handler_2:;
