@@ -997,7 +997,7 @@ int Sregex_match(char *pattern, char *text, int flag)
  ret= regexec(&re, text, 1, match, 0);
  regfree(&re);
  if(ret != 0)
-   goto ex;
+   {ret= 0; goto ex;}
  ret= 1;
 ex:;
  if(re_text != NULL)
@@ -1218,3 +1218,19 @@ char *Xorriso__hide_mode_text(int hide_mode, int flag)
  return "invalid";
 }
 
+
+/* @return 0=truncated, 1=ok
+*/
+int Xorriso__to_upper(char *in, char *out, int out_size, int flag)
+{
+ int i;
+
+ for(i= 0; i < out_size - 1 && in[i] != 0; i++)
+   if(isalpha(in[i]))
+     out[i]= toupper(in[i]);
+   else
+     out[i]= in[i];
+ out[i]= 0;
+ return(in[i] == 0);
+}
+
