@@ -1368,7 +1368,7 @@ ex:;
    xorriso->pacifier_interval= mem_pci;
    if(mem_lut!=xorriso->last_update_time && !(flag&2))
      Xorriso_pacifier_callback(xorriso, "content bytes read",
-                               xorriso->pacifier_count, 0, "", 1);
+                               xorriso->pacifier_count, 0, "", 1 | 8 | 32);
  }
  if(do_report) {
    if(optc == 0) {
@@ -1943,7 +1943,7 @@ int Xorriso_option_compare(struct XorrisO *xorriso, char *disk_path,
  xorriso->pacifier_interval= mem_pci;
  if(mem_lut!=xorriso->last_update_time && !(flag&2))
    Xorriso_pacifier_callback(xorriso, "content bytes read",
-                             xorriso->pacifier_count, 0, "", 1);
+                             xorriso->pacifier_count, 0, "", 1 | 8 | 32);
 report_outcome:;
  if(ret>0) {
    sprintf(xorriso->result_line,
