@@ -617,7 +617,7 @@ int Xorriso_option_map_l(struct XorrisO *xorriso, int argc, char **argv,
                              xorriso->pacifier_total, "", 1);
  else if(mode==1 || mode==2)
    Xorriso_pacifier_callback(xorriso, "content bytes read",
-                             xorriso->pacifier_count, 0, "", 1);
+                             xorriso->pacifier_count, 0, "", 1 | 8 | 32);
  else if(mode==3)
    Xorriso_pacifier_callback(xorriso, "files restored",xorriso->pacifier_count,
                              xorriso->pacifier_total, "", 1|4);
