@@ -1,7 +1,7 @@
 
 /* xorriso - creates, loads, manipulates and burns ISO 9660 filesystem images.
 
-   Copyright 2007-2011 Thomas Schmitt, <scdbackup@gmx.net>
+   Copyright 2007-2012 Thomas Schmitt, <scdbackup@gmx.net>
 
    Provided under GPL version 2 or later.
 
@@ -691,7 +691,6 @@ int Xorriso_option_session_log(struct XorrisO *xorriso, char *path, int flag)
 }
 
 
-
 /* Option -setfacl_list alias -setfacl_listi */
 int Xorriso_option_setfacl_listi(struct XorrisO *xorriso, char *path, int flag)
 {
@@ -1217,6 +1216,38 @@ int Xorriso_option_signal_handling(struct XorrisO *xorriso, char *mode,
 }
 
 
+/* Option -sleep */
+int Xorriso_option_sleep(struct XorrisO *xorriso, char *duration, int flag)
+{
+ double dur= 0.0, start_time, end_time, todo, granularity= 0.01;
+ unsigned long usleep_time; 
+
+ sscanf(duration, "%lf", &dur);
+ start_time= Sfile_microtime(0);
+ end_time= start_time + dur;
+ Ftimetxt(time(NULL), xorriso->info_text, 6);
+ sprintf(xorriso->info_text + strlen(xorriso->info_text),
+         " : Will sleep for %f seconds", dur);
+ Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "UPDATE", 0);
+ while(1) {
+   todo= end_time - Sfile_microtime(0);
+   if(todo <= 0)
+     usleep_time= 0;
+   else if(todo > granularity)
+     usleep_time= granularity * 1.0e6;
+   else
+     usleep_time= todo * 1.0e6;
+   if(usleep_time == 0)
+ break;
+   usleep(usleep_time);
+ }
+ sprintf(xorriso->info_text, "Slept for %f seconds",
+         Sfile_microtime(0) - start_time);
+ Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "DEBUG", 0);
+ return(1);
+}
+
+
 /* Option -speed */
 int Xorriso_option_speed(struct XorrisO *xorriso, char *speed, int flag)
 {
@@ -1398,7 +1429,7 @@ int Xorriso_option_tell_media_space(struct XorrisO *xorriso, int flag)
  }
  if(free_space<0) {
    sprintf(xorriso->info_text,
-           "Pending image size larger than free space on media");
+           "Pending image size larger than free space on medium");
    Xorriso_msgs_submit(xorriso, 0, xorriso->info_text, 0, "WARNING", 0);
  }
  sprintf(xorriso->result_line, "Media space  : %ds\n", media_space);
@@ -1638,7 +1669,7 @@ int Xorriso_option_update(struct XorrisO *xorriso, char *disk_path,
  xorriso->pacifier_interval= mem_pci;
  if(mem_lut!=xorriso->last_update_time && !(flag & (2 | 4)))
    Xorriso_pacifier_callback(xorriso, "content bytes read",
-                             xorriso->pacifier_count, 0, "", 1);
+                             xorriso->pacifier_count, 0, "", 1 | 8 | 32);
 report_outcome:;
  if(ret>0) {
    sprintf(xorriso->info_text,
@@ -1707,7 +1738,7 @@ int Xorriso_option_version(struct XorrisO *xorriso, int flag)
  sprintf(xorriso->result_line,
 "ISO 9660 Rock Ridge filesystem manipulator and CD/DVD/BD burn program\n");
  sprintf(xorriso->result_line+strlen(xorriso->result_line),
-"Copyright (C) 2011, Thomas Schmitt <scdbackup@gmx.net>, libburnia project.\n");
+"Copyright (C) 2012, Thomas Schmitt <scdbackup@gmx.net>, libburnia project.\n");
  Xorriso_result(xorriso, 0);
  sprintf(xorriso->result_line,
          "xorriso version   :  %d.%d.%d%s\n",
