@@ -1863,8 +1863,8 @@ int Xorriso_extract_cut(struct XorrisO *xorriso,
    goto ex;
 
  if(mem_lut != xorriso->last_update_time)
-   Xorriso_pacifier_callback(xorriso, "sectors examined",
-                             xorriso->pacifier_count, 0, "", 1);
+   Xorriso_pacifier_callback(xorriso, "blocks read",
+                             xorriso->pacifier_count, 0, "", 1 | 8 | 16 | 32);
  ret= 1;
 ex:;
  Xorriso_free_meM(eff_img_path);
@@ -2088,7 +2088,7 @@ int Xorriso_check_md5(struct XorrisO *xorriso, void *in_node, char *path,
    xorriso->pacifier_count+= rret; 
    xorriso->pacifier_byte_count+= rret;
    Xorriso_pacifier_callback(xorriso, "content bytes read",
-                             xorriso->pacifier_count, 0, "", 0);
+                             xorriso->pacifier_count, 0, "", 8);
    ret= Xorriso_check_for_abort(
              xorriso,
              xorriso->check_media_default != NULL 
